==> aidlab_sdk-0.0.19.tar.gz: pigeons/aidlab_delegate.dart <==
// @dart=2.9
import 'package:pigeon/pigeon.dart';

import 'empty_event.dart';

@FlutterApi()
abstract class PlatformAidlabDelegate {
  void didConnect(ConnectEvent connectEvent);

  void didDisconnect(DisconnectEvent voidEvent);

  void didReceiveEcg(EcgEvent ecgEvent);

  void didReceiveRespiration(RespirationEvent respirationEvent);

  void didReceiveRespirationRate(RespirationRateEvent respirationRateEvent);

  void didReceiveBatteryLevel(BatteryLevelEvent batteryLevelEvent);

  void didReceiveSkinTemperature(SkinTemperatureEvent skinTemperatureEvent);

  void didReceiveAccelerometer(VectorEvent vectorEvent);

  void didReceiveGyroscope(VectorEvent vectorEvent);

  void didReceiveMagnetometer(VectorEvent vectorEvent);

  void didReceiveQuaternion(QuaternionEvent quaternionEvent);

  void didReceiveOrientation(OrientationEvent orientationEvent);

  void didReceiveBodyPosition(BodyPositionEvent bodyPositionEvent);

  void didReceiveActivity(ActivityEvent activityEvent);

  void didReceiveSteps(StepsEvent stepsEvent);

  void didReceiveHeartRate(HeartRateEvent heartRateEvent);

  void didReceiveHrv(HrvEvent hrvEvent);

  void wearStateDidChange(WearStateEvent wearStateEvent);

  void didDetectExercise(ExerciseEvent exerciseEvent);

  void didReceiveSoundVolume(SoundVolumeEvent soundVolumeEvent);

  void didReceiveCommand(EmptyEvent voidEvent);

  void didReceiveError(ErrorEvent errorEvent);

  void didReceiveMessage(MessageEvent messageEvent);

  void didDetectUserEvent(UserEvent userEvent);

  void didReceiveSoundFeatures(SoundFeaturesEvent soundFeaturesEvent);

  void didReceiveSignalQuality(SignalQualityEvent signalQualityEvent);
}

class ConnectEvent {
  String firmwareRevision;
  String hardwareRevision;
  String serialNumber;
  String address;
}

class EcgEvent {
  int timestamp;
  Float64List values;
}

class RespirationEvent {
  int timestamp;
  Float64List values;
}

class RespirationRateEvent {
  int timestamp;
  int value;
}

class BatteryLevelEvent {
  int stateOfCharge;
}

class VectorEvent {
  int timestamp;
  double x;
  double y;
  double z;
}

class QuaternionEvent {
  int timestamp;
  double qw;
  double qx;
  double qy;
  double qz;
}

class OrientationEvent {
  int timestamp;
  double roll;
  double pitch;
  double yaw;
}

class BodyPositionEvent {
  int timestamp;
  int bodyPosition;
}

class ActivityEvent {
  int timestamp;
  int activityType;
}

class StepsEvent {
  int timestamp;
  int value;
}

class HeartRateEvent {
  int timestamp;
  int heartRate;
}

class HrvEvent {
  int timestamp;
  int hrv;
}

class WearStateEvent {
  int wearState;
}

class SkinTemperatureEvent {
  int timestamp;
  double value;
}

class ExerciseEvent {
  int exercise;
}

class SoundVolumeEvent {
  int timestamp;
  int soundVolume;
}

class ErrorEvent {
  String error;
}

class MessageEvent {
  String process;
  String message;
}

class UserEvent {
  int timestamp;
}

class SoundFeaturesEvent {
  Float64List values;
}

class DisconnectEvent {
  int disconnectReason;
}

class SignalQualityEvent {
  int timestamp;
  int value;
}

==> aidlab_sdk-0.0.21.tar.gz: pigeons/aidlab_delegate.dart <==
// @dart=2.9
import 'package:pigeon/pigeon.dart';

import 'empty_event.dart';

@FlutterApi()
abstract class PlatformAidlabDelegate {
  void didConnect(ConnectEvent connectEvent);

  void didDisconnect(DisconnectEvent voidEvent);

  void didReceiveEcg(EcgEvent ecgEvent);

  void didReceiveRespiration(RespirationEvent respirationEvent);

  void didReceiveRespirationRate(RespirationRateEvent respirationRateEvent);

  void didReceiveBatteryLevel(BatteryLevelEvent batteryLevelEvent);

  void didReceiveSkinTemperature(SkinTemperatureEvent skinTemperatureEvent);

  void didReceiveAccelerometer(VectorEvent vectorEvent);

  void didReceiveGyroscope(VectorEvent vectorEvent);

  void didReceiveMagnetometer(VectorEvent vectorEvent);

  void didReceiveQuaternion(QuaternionEvent quaternionEvent);

  void didReceiveOrientation(OrientationEvent orientationEvent);

  void didReceiveBodyPosition(BodyPositionEvent bodyPositionEvent);

  void didReceiveActivity(ActivityEvent activityEvent);

  void didReceiveSteps(StepsEvent stepsEvent);

  void didReceiveHeartRate(HeartRateEvent heartRateEvent);

  void didReceiveRr(RrEvent rrEvent);

  void wearStateDidChange(WearStateEvent wearStateEvent);

  void didDetectExercise(ExerciseEvent exerciseEvent);

  void didReceiveSoundVolume(SoundVolumeEvent soundVolumeEvent);

  void didReceiveCommand(EmptyEvent voidEvent);

  void didReceiveError(ErrorEvent errorEvent);

  void didReceiveMessage(MessageEvent messageEvent);

  void didDetectUserEvent(UserEvent userEvent);

  void didReceiveSoundFeatures(SoundFeaturesEvent soundFeaturesEvent);

  void didReceiveSignalQuality(SignalQualityEvent signalQualityEvent);
}

class ConnectEvent {
  String firmwareRevision;
  String hardwareRevision;
  String serialNumber;
  String address;
}

class EcgEvent {
  int timestamp;
  Float64List values;
}

class RespirationEvent {
  int timestamp;
  Float64List values;
}

class RespirationRateEvent {
  int timestamp;
  int value;
}

class BatteryLevelEvent {
  int stateOfCharge;
}

class VectorEvent {
  int timestamp;
  double x;
  double y;
  double z;
}

class QuaternionEvent {
  int timestamp;
  double qw;
  double qx;
  double qy;
  double qz;
}

class OrientationEvent {
  int timestamp;
  double roll;
  double pitch;
  double yaw;
}

class BodyPositionEvent {
  int timestamp;
  int bodyPosition;
}

class ActivityEvent {
  int timestamp;
  int activityType;
}

class StepsEvent {
  int timestamp;
  int value;
}

class HeartRateEvent {
  int timestamp;
  int heartRate;
}

class RrEvent {
  int timestamp;
  int rr;
}

class WearStateEvent {
  int wearState;
}

class SkinTemperatureEvent {
  int timestamp;
  double value;
}

class ExerciseEvent {
  int exercise;
}

class SoundVolumeEvent {
  int timestamp;
  int soundVolume;
}

class ErrorEvent {
  String error;
}

class MessageEvent {
  String process;
  String message;
}

class UserEvent {
  int timestamp;
}

class SoundFeaturesEvent {
  Float64List values;
}

class DisconnectEvent {
  int disconnectReason;
}

class SignalQualityEvent {
  int timestamp;
  int value;
}
